<template>
  <div style="height:100%">
    <el-form
      ref="form"
      :model="form"
      label-width="70px"
      style="display:flex;height:45px;"
    >
      <el-form-item label="需求时间">
        <el-date-picker
          v-model="form.searchDate"
          type="datetimerange"
          unlink-panels
          range-separator="—"
          start-placeholder="请选择开始日期"
          end-placeholder="请选择结束日期"
          value-format="yyyy-MM-dd HH:mm:ss"
          style="width:335px"
        >
        </el-date-picker>
      </el-form-item>
      <el-form-item label="需求系统" label-width="75px">
        <el-input
          v-model="form.demandSysName"
          placeholder="请输入系统"
          clearable
          style="width:120px"
        ></el-input>
      </el-form-item>
      <el-form-item label="机组名称" label-width="75px">
        <el-select
          v-model="fanCode"
          placeholder="请选择机组"
          clearable
          style="width:120px"
        >
          <el-option
            v-for="item in fanCodeList"
            :key="item.value"
            :label="item.label"
            :value="item.value"
          ></el-option>
        </el-select>
      </el-form-item>
      <el-form-item label="命令" label-width="45px">
        <el-select
          v-model="orderName"
          placeholder="请选择命令"
          clearable
          style="width:120px"
        >
          <el-option
            v-for="item in orderNameList"
            :key="item.value"
            :label="item.label"
            :value="item.value"
          ></el-option>
        </el-select>
      </el-form-item>
      <el-form-item label="下发状态">
        <el-select
          v-model="form.status"
          clearable
          placeholder="请选择"
          style="width:120px"
        >
          <el-option label="已下发" :value="1"> </el-option>
          <el-option label="不下发" :value="0"> </el-option>
        </el-select>
      </el-form-item>
      <el-form-item label-width="0">
        <el-button
          style="margin-left: 10px"
          size="small"
          type="primary"
          icon="el-icon-search"
          @click="loadData"
          >查询</el-button
        >
        <el-button size="small" icon="el-icon-refresh" @click="handleRefresh" class="reset"
          >重置</el-button
        >
        <el-button size="small" icon="el-icon-delete" @click="handleDelete" type="danger"
          >删除</el-button
        >
      </el-form-item>
    </el-form>
    <div class="table-container">
      <el-table :data="tableData" style="width: 100%" height="100%" @selection-change="handleSelectionChange"
        :default-sort="{prop:'demandTime'}">
        <el-table-column align="center" label="控制需求">
          <el-table-column
            type="selection"
            width="40">
          </el-table-column>
          <el-table-column
            align="center"
            prop="demandTime"
            label="需求时间"
            sortable
            show-overflow-tooltip
          >
          </el-table-column>
          <el-table-column
            align="center"
            prop="demandSysName"
            label="需求系统"
            sortable
            show-overflow-tooltip
          >
          </el-table-column>
          <el-table-column
            align="center"
            prop="fanName"
            label="机组名称"
            sortable
            show-overflow-tooltip
          >
          </el-table-column>
          <el-table-column
            align="center"
            prop="orderName"
            label="命令"
            show-overflow-tooltip
          >
          </el-table-column>
          <el-table-column
            align="center"
            prop="orderCode"
            label="命令代码"
            sortable
            show-overflow-tooltip
          >
          </el-table-column>
          <el-table-column
            align="center"
            prop="orderParams"
            label="命令参数"
            show-overflow-tooltip
          >
          </el-table-column>
        </el-table-column>
        <el-table-column align="center" label="控制决策">
          <el-table-column
            align="center"
            prop="decisionTime"
            label="下发时间"
            sortable
            show-overflow-tooltip
          >
          </el-table-column>
          <el-table-column
            align="center"
            prop="decisionState"
            label="下发状态"
            sortable
            show-overflow-tooltip
          >
            <template slot-scope="scope">
              <el-tag effect="dark" v-if="scope.row.decisionState == 1">
                已下发
              </el-tag>
              <el-tag
                effect="dark"
                type="info"
                v-if="scope.row.decisionState == 0"
              >
                不下发
              </el-tag>
            </template>
          </el-table-column>
        </el-table-column>
        <el-table-column align="center" label="执行结果">
          <el-table-column
            align="center"
            prop="executeResult"
            label="执行结果"
            show-overflow-tooltip
          >
            <template slot-scope="scope">
              <el-tag effect="dark" v-if="scope.row.executeState == 1">
                已执行
              </el-tag>
              <el-tag
                effect="dark"
                type="info"
                v-if="scope.row.executeState == 0"
              >
                未执行
              </el-tag>
              <el-tag
                effect="dark"
                type="warning"
                v-if="scope.row.executeState == 2"
              >
                已完成
              </el-tag>
            </template>
          </el-table-column>
        </el-table-column>
        <el-table-column align="center" label="操作">
          <el-table-column
            align="center"
            prop="action"
            label="操作"
            show-overflow-tooltip
          >
            <template slot-scope="scope">
              <el-button type="primary" icon="el-icon-thumb" @click="handleClick(scope.row)">下发</el-button>
            </template>
          </el-table-column>
        </el-table-column>
      </el-table>
    </div>
    <el-pagination
      small
      class="table-page"
      @size-change="handleSizeChange"
      @current-change="handleCurrentChange"
      :current-page="currentPage"
      :pager-count="11"
      :page-sizes="[10, 20, 50, 100, 200, 300, 500]"
      :page-size="pageSize"
      layout="total, sizes, prev, pager, next, jumper"
      :total="total"
    >
    </el-pagination>
  </div>
</template>
<script>
export default {
  name: 'intelligent-control',
  data() {
    return {
      form: {
        searchDate: [],
        demandSysName: '',
        fanCode: '',
        orderName: '',
        status: ''
      },
      tableData: [],
      fanCodeList: [], //获取机编号
      orderNameList: [], //获取命令
      currentPage: 1,
      total: 0,
      pageSize: 50,
      fanCode: '',
      orderName: '',
      multipleSelection: []
    }
  },
  created() {
    this.loadData()
    this.loadFanCode()
    this.loadOrder()
  },
  methods: {
    // 测试操作
    handleClick(row){
      let query = {
        url: '${cssc}/biz/model/order/v1/executeOrderById',
        method: 'POST',
        headers: {
          'Content-type': 'application/x-www-form-urlencoded'
        },
        data: this.qs.stringify({
          id: row.id
        })
      }
      this.$http.request(query)
        .then(res => {
          if(res.success){
            this.$message.success('已下发')
          }else{
            this.$message.warning(res.message)
          }
        })
    },
    //初始查询命令
    loadOrder() {
      this.$http.post('${cssc}/biz/model/orderInfo/v1/list').then(res => {
        let row = res.data
        for (var i = 0; i < row.length; i++) {
          let obj = {}
          obj.label = row[i].orderName
          obj.value = row[i].orderCode
          this.orderNameList.push(obj)
        }
      })
    },
    //初始查询机组编号
    loadFanCode() {
      let query = {
        sorter: [{direction: 'ASC', property: 'sn'}]
      }
      this.$http.post('${cssc}/biz/base/fanInfo/v1/list', query).then(
        res => {
          let row = res.data
          for (var i = 0; i < row.length; i++) {
            let obj = {}
            obj.label = row[i].fanName
            obj.value = row[i].fanCode
            this.fanCodeList.push(obj)
          }
        },
        error => {
          reject(error)
        }
      )
    },
    handleSelectionChange(val){
      this.multipleSelection = val;
    },
    handleDelete(){
      if(!this.multipleSelection.length){
         this.$message.warning('请选择要删除的数据！')
         return
      }
      let queryStr = ''
      let ids = this.multipleSelection.map(item=>{
        queryStr += '&ids=' + item.id
        return ids
      })
      queryStr = queryStr.slice(1)
      let query = {
        url: '${cssc}/biz/model/order/v1/?' + queryStr,
        method: 'delete',
      }
      this.$http.request(query)
        .then(res => {
          if(res.data && res.data.state){
            this.$message.success('删除成功')
            this.loadData()
          }else{
            this.$message.warning(res.data.state)
          }
        })
    },
    handleRefresh() {
      this.form = {
        searchDate: [],
        demandSysName: '',
        fanCode: '',
        orderName: '',
        status: ''
      }
      this.fanCode = ''
      this.orderName = ''
      // 请求列表数据
      this.loadData()
    },
    loadData(val) {
      let param = {
        pageBean: {
          page: this.currentPage,
          pageSize: this.pageSize,
          total: 0
        },
        querys: [],
        sorter: [{
          "direction": "DESC",
			    "property": "demandTime"
        }]
      }
      let searchQuerys = [
        {
          group: 'main',
          operation: 'BETWEEN',
          parentGroup: '',
          property: 'demandTime',
          relation: 'AND',
          value: this.form.searchDate?this.form.searchDate:[]
        },
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'demandSysName',
          relation: 'AND',
          value: this.form.demandSysName
        },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'fanCode',
          relation: 'AND',
          value: this.fanCode
        },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'orderCode',
          relation: 'AND',
          value: this.orderName
        },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'decisionState',
          relation: 'AND',
          value: this.form.status
        }
      ]

      let newQuerys = []
      searchQuerys.forEach((val, index) => {
        if (val['value'] != '') {
          newQuerys.push(searchQuerys[index])
        } else if (val['value'] === 0 || val['value'] === 1) {
          newQuerys.push(searchQuerys[index])
        }
      })
      param.querys = newQuerys

      this.$http.post('${cssc}/biz/model/order/v1/query', param).then(res => {
        let resp = res.data
        // console.log(resp)
        this.tableData = resp.rows
        this.currentPage = resp.page
        this.pageSize = resp.pageSize
        this.total = resp.total
      })
    },
    //每页显示多少条数目
    handleSizeChange(val) {
      this.pageSize = val
      this.loadData()
    },
    //点击跳到几页
    handleCurrentChange(val) {
      this.currentPage = val
      this.loadData()
    }
  }
}
</script>
<style lang="scss" scoped>
@import '@/assets/css/element-variables.scss';

.table-container {
  height: calc(100% - 84px);
}
.table-page {
  text-align: right;
  padding: 10px 0;
  /deep/ .el-input__inner {
    height: 23px !important;
    line-height: 23px !important;
  }
}
/deep/ .el-form-item__label {
  padding-right: 5px;
}
/deep/ .el-button--small {
  padding: 8px 10px;
}
/deep/ .el-range-input {
  background-color: $--background-color-secondary;
  color: $--color-text;
}
/deep/ .el-table thead.is-group th {
  background-color: $--table-title-bgcolor;
}

/deep/ .el-picker-panel__footer {
  background-color: $--table-bgcolor !important;
}
/* author: LL*/
/deep/ .el-table__header .has-gutter tr th {
  border: 1px solid #bff2dd !important;
  border-left: none !important;
}
/deep/.el-table__header .has-gutter tr:nth-child(1) th {
  border-bottom: none !important;
}
/deep/ .el-date-editor .el-range-separator {
  color: #fff;
}
/deep/ .el-button.is-disabled.is-plain {
  background: $--light-border;
}
//设置el的第二个按钮背景颜色
.el-button.reset {
  background: $--hover-bgcolor;
  color: #fff;
  border: 1px solid #1a7aa0;
}
.el-button.reset:hover {
  background: rgba($--hover-bgcolor, 0.7);
  color: $--color-text;
}
/deep/ .el-checkbox__inner{
  background-color: #123c58;
  border-color: #bff2dd;
}
</style>
